@@ -85,8 +85,8 @@ def validate_conf(asset_conf):
         raise AssetBuilderException('The asset configuration does not contain the required field "name".')
 
     # Validate runSpec
-    if 'release' not in asset_conf or asset_conf['release'] not in ["16.04", "14.04", "12.04"]:
-        raise AssetBuilderException('The "release" field value should be either "16.04", "14.04", or "12.04" (DEPRECATED)')
+    if 'release' not in asset_conf or asset_conf['release'] not in ["20.04", "16.04", "14.04", "12.04"]:
+        raise AssetBuilderException('The "release" field value should be either "20.04", "16.04", "14.04" (DEPRECATED), or "12.04" (DEPRECATED)')
     if 'runSpecVersion' in asset_conf:
         if asset_conf['runSpecVersion'] not in ["0", "1"]:
             raise AssetBuilderException('The "runSpecVersion" field should be either "0", or "1"')
@@ -106,7 +106,7 @@ def validate_conf(asset_conf):
         raise AssetBuilderException('The asset configuration does not contain the required field "title". ')
     if 'description' not in asset_conf:
         raise AssetBuilderException('The asset configuration does not contain the required field "description".')
-    
+
 
 
 def dx_upload(file_name, dest_project, target_folder, json_out):
