@@ -108,6 +108,12 @@ class DXExecutable:
         if kwargs.get('rank') is not None:
             run_input["rank"] = kwargs['rank']
 
+        if kwargs.get('max_tree_spot_wait_time') is not None:
+            run_input["maxTreeSpotWaitTime"] = kwargs['max_tree_spot_wait_time']
+
+        if kwargs.get('max_job_spot_wait_time') is not None:
+            run_input["maxJobSpotWaitTime"] = kwargs['max_job_spot_wait_time']
+
         return run_input
 
     @staticmethod
@@ -121,7 +127,7 @@ class DXExecutable:
         for unsupported_arg in ['stage_instance_types', 'stage_folders', 'rerun_stages', 'ignore_reuse_stages']:
             if kwargs.get(unsupported_arg):
                 raise DXError(unsupported_arg + ' is not supported for applets (only workflows)')
-        
+
         run_input = DXExecutable._get_run_input_common_fields(executable_input, **kwargs)
 
         if kwargs.get('head_job_on_demand') is not None:
@@ -172,8 +178,9 @@ class DXExecutable:
 
     def run(self, executable_input, project=None, folder=None, name=None, tags=None, properties=None, details=None,
             instance_type=None, stage_instance_types=None, stage_folders=None, rerun_stages=None, cluster_spec=None,
-            depends_on=None, allow_ssh=None, debug=None, delay_workspace_destruction=None, priority=None, head_job_on_demand=None, 
-            ignore_reuse=None, ignore_reuse_stages=None, detach=None, cost_limit=None, rank=None, extra_args=None, **kwargs):
+            depends_on=None, allow_ssh=None, debug=None, delay_workspace_destruction=None, priority=None, head_job_on_demand=None,
+            ignore_reuse=None, ignore_reuse_stages=None, detach=None, cost_limit=None, rank=None, max_tree_spot_wait_time=None,
+            max_job_spot_wait_time=None, extra_args=None, **kwargs):
         '''
         :param executable_input: Hash of the executable's input arguments
         :type executable_input: dict
@@ -211,8 +218,12 @@ class DXExecutable:
         :type detach: boolean
         :param cost_limit: Maximum cost of the job before termination.
         :type cost_limit: float
-        :param rank: Rank of execution 
+        :param rank: Rank of execution
         :type rank: int
+        :param max_tree_spot_wait_time: Number of seconds allocated to each path in the root execution's tree to wait for Spot
+        :type max_tree_spot_wait_time: int
+        :param max_job_spot_wait_time: Number of seconds allocated to each job in the root execution's tree to wait for Spot
+        :type max_job_spot_wait_time: int
         :param extra_args: If provided, a hash of options that will be merged into the underlying JSON given for the API call
         :type extra_args: dict
         :returns: Object handler of the newly created job
@@ -249,6 +260,8 @@ class DXExecutable:
                                         detach=detach,
                                         cost_limit=cost_limit,
                                         rank=rank,
+                                        max_tree_spot_wait_time=max_tree_spot_wait_time,
+                                        max_job_spot_wait_time=max_job_spot_wait_time,
                                         extra_args=extra_args)
         return self._run_impl(run_input, **kwargs)
 
