@@ -225,7 +225,7 @@ def validate_ignore_reuse(stages, ignore_reuse_stages):
          raise WorkflowBuilderException('"IgnoreReuse must be a list of strings - stage IDs or "*"')
 
     ignore_reuse_set = set(ignore_reuse_stages)
-    if '*' in ignore_reuse_set and ignore_reuse_set == 1:
+    if '*' in ignore_reuse_set and len(ignore_reuse_set) == 1:
         return
 
     stage_ids = set([stage.get('id') for stage in stages])
@@ -323,9 +323,9 @@ def _get_validated_json(json_spec, args):
     if 'stages' in validated_spec:
         validated_spec['stages'] = _get_validated_stages(validated_spec['stages'])
 
-    if 'name' in validated_spec:
+    if 'name' in validated_spec and not args._from:
         dir_name = os.path.basename(os.path.normpath(args.src_dir))
-        if not args._from and dir_name != validated_spec['name']:
+        if dir_name != validated_spec['name']:
             logger.warn(
                 'workflow name "{}" does not match containing directory "{}"'.format(validated_spec['name'], dir_name))
 
